@@ -2,6 +2,7 @@
 using namespace Rcpp;
 
 #define TINYOBJLOADER_IMPLEMENTATION
+#define TINYOBJLOADER_USE_MAPBOX_EARCUT
 #include "tiny_obj_loader.h"
 
 template <typename T>
@@ -87,8 +88,8 @@ List load_obj(std::string inputfile, std::string basedir) {
   for(unsigned int i=0; i < materials.size(); i++) {
     tinyobj::material_t m = materials[i];
     int culltype = m.dissolve < 1.0 ? 3 : 1; //no culling if at all transparent
-    List out(26);
-    CharacterVector names(26) ;
+    List out(27);
+    CharacterVector names(27) ;
     
     set_item( out, 0 , _["ambient"]  =  NumericVector::create(m.ambient[0], m.ambient[1], m.ambient[2]), names) ;
     set_item( out, 1 , _["diffuse"]  = NumericVector::create(m.diffuse[0], m.diffuse[1], m.diffuse[2]), names) ;
@@ -116,13 +117,14 @@ List load_obj(std::string inputfile, std::string basedir) {
     set_item( out, 23, _["toon_outline_color"] = "black", names) ;
     set_item( out, 24, _["reflection_intensity"] = 1.0, names) ;
     set_item( out, 25, _["reflection_sharpness"] = 1.0, names) ;
+    set_item( out, 26, _["two_sided"] = false, names) ;
     
     out.names() = names ;
-    material_list[m.name] = out;
+    material_list.push_back(out);
   }
   List return_val;
   return_val["shapes"]    = shape_list;
-  return_val["materials"] = material_list;
+  return_val["materials"] = List::create(material_list);
   return_val["vertices"]  = List::create(Rcpp::transpose(NumericMatrix(3L, attrib.vertices.size()/3L, attrib.vertices.begin())));
   return_val["texcoords"] = List::create(Rcpp::transpose(NumericMatrix(2L, attrib.texcoords.size()/2L, attrib.texcoords.begin())));
   return_val["normals"]   = List::create(Rcpp::transpose(NumericMatrix(3L, attrib.normals.size()/3L, attrib.normals.begin())));
